Model
=====

The cimsparql.model module contains the base class SingleClientModel for both
:doc:`graphdb.GraphDBClient <graphdb>` get_table as well as a set of
predefined CIM queries.

.. automodule:: cimsparql.model
   :members:
   :undoc-members:
   :show-inheritance:
